import os
from configparser import ConfigParser

from pa_pylibs.setup.install_application import InstallApplication
from pa_pylibs.setup.models.filesystem_object import Directory
from setuptools import find_packages, setup

from backup_now import resources

APPLICATION_NAME = 'backup_now'

UID = os.getgid()
GID = os.getgid()

FILESYSTEM_RESOURCES = [
    Directory('~/.backup_now', UID, GID, 0o700),
    Directory('~/.backup_now/logs', UID, GID, 0o700),
    Directory('~/.backup_now/lock_files', UID, GID, 0o700)
]


class InstallBackupNow(InstallApplication):
    """
    Installs the backup_now application
    """

    def __init__(self, dist):
        super().__init__(dist, APPLICATION_NAME, FILESYSTEM_RESOURCES, resources.__path__[0])

    @staticmethod
    def _generate_config():
        config_path = os.path.expanduser('~/.backup_now/backup_now.conf')

        if not os.path.exists(config_path):
            generate_config = input('Would you like to generate a config file? (y/n): ')

            if generate_config == 'y':
                onsite_path = input('Enter the path to your mounted backup share: ')
                backblaze_account_id = input('Enter your Backblaze account ID: ')
                backblaze_account_application_key = input('Enter your Backblaze B2 Application Key: ')
                backblaze_bucket_name = input('Enter the name of the B2 Bucket to use: ')
                backblaze_path = input('Enter the path within the B2 Bucket to backup to: ')

                smtp_host_port = input('Enter the SMTP host:port: ')
                smtp_user_name = input('Enter the SMTP server user name: ')
                smtp_password = input('Enter the SMTP server password: ')
                smtp_from_address = input('Enter the from address: ')

                encryption_passphrase_path = input('Enter the path to a file containing your encryption key: ')

                config = ConfigParser()
                config.add_section('nas_share')
                config.add_section('b2')
                config.add_section('email')
                config.add_section('encryption')

                config.set('nas_share', 'path', onsite_path)

                config.set('b2', 'account_id', backblaze_account_id)
                config.set('b2', 'application_key', backblaze_account_application_key)
                config.set('b2', 'bucket_name', backblaze_bucket_name)
                config.set('b2', 'path', backblaze_path)

                config.set('email', 'smtp_hostport', smtp_host_port)
                config.set('email', 'username', smtp_user_name)
                config.set('email', 'password', smtp_password)
                config.set('email', 'from_address', smtp_from_address)

                config.set('encryption', 'passphrase_path', encryption_passphrase_path)

                with open(config_path, 'w') as config_file:
                    config.write(config_file)


setup(
    name='backup_now',
    version='1.0.1',
    packages=find_packages(exclude=['tests']),
    scripts=['bin/backup_now'],
    url='http://www.patrickayoup.com/backup_now/',
    download_url='https://github.com/patrickayoup/pa_pylibs/tarball/1.0.1',
    license='MIT',
    author='Patrick Ayoup',
    author_email='patrick.ayoup@gmail.com',
    description='Wrapper for scripting duplicity.',
    setup_requires=[
        'pa-pylibs'
    ],
    install_requires=[
        'fasteners'
    ],
    cmdclass={
        'install': InstallBackupNow
    },
    keywords=['backups', 'duplicity']
)
